@@ -261,7 +261,7 @@ basepath = os.path.expanduser('~/share/bby/')
   };
 
   var sync_bby_lesson = function () {
-    const pathRegRes = /userdata\/lessons-(\d+)-(\w+)\.ipynb/.exec(
+    const pathRegRes = /work\/lessons-(\d+)-(\w+)\.ipynb/.exec(
       Jupyter.notebook.notebook_path
     );
     const lessonId = Number(pathRegRes[1]);
@@ -306,7 +306,7 @@ basepath = os.path.expanduser('~/share/bby/')
   var addButtons = function () {
     // 是系统创建的bby lesson，可以同步到波波鱼
     if (
-      /userdata\/lessons-(\d+)-(\w+)\.ipynb/.test(
+      /work\/lessons-(\d+)-(\w+)\.ipynb/.test(
         Jupyter.notebook.notebook_path
       )
     ) {
